@@ -54,7 +54,7 @@ def get_all_servers():
 
 class Testbed(adt_testbed.Testbed):
 
-    def check_exec2(self, argv, stdout=False, kind='short', xenv=[]):
+    def check_exec2(self, argv, stdout=False, kind='install', xenv=[]):
         """Like check_exec but does not bomb on stderr, and can pass xenv."""
         (code, out, err) = self.execute(argv,
                                         stdout=(stdout and subprocess.PIPE or None),
