@@ -49,8 +49,12 @@ SYSTEM_INTERFACES = {
         'fedora': FedoraInterface,
         }
 
-timeouts = {'short': 100, 'copy': 300, 'install': 3000, 'test': 10000,
-            'build': 100000}
+timeouts = {
+    'copy': int(os.getenv('REPROTEST_TIMEOUT_COPY', 300)),
+    'install': int(os.getenv('REPROTEST_TIMEOUT_INSTALL', 3000)),
+    'test': int(os.getenv('REPROTEST_TIMEOUT_TEST', 10000)),
+    'build': int(os.getenv('REPROTEST_TIMEOUT_BUILD', 100000)),
+}
 
 
 class Testbed:
@@ -431,7 +435,7 @@ class Testbed:
             ll = list(map(urllib.parse.unquote, ll))
         return ll
 
-    def execute(self, argv, xenv=[], stdout=None, stderr=None, kind='short'):
+    def execute(self, argv, xenv=[], stdout=None, stderr=None, kind='install'):
         '''Run command in testbed.
 
         The commands stdout/err will be piped directly to autopkgtest and its log
@@ -489,7 +493,7 @@ class Testbed:
 
         return (proc.returncode, out, err)
 
-    def check_exec(self, argv, stdout=False, kind='short'):
+    def check_exec(self, argv, stdout=False, kind='install'):
         '''Run argv in testbed.
 
         If stdout is True, capture stdout and return it. Otherwise, don't
